############ TCL FILE #####################################
#########################################################
# Description						 #			
# Postprocessor for machine: BOKO				 #
# CNC Control: HAIDENHAIN TNC 355 				 #
# Revisions						 #
#							 #
#   Date            		Who        		Reason		 #
#  25-Oct-2001		Oleg Chizh 	First Release	 #
#							 #
# $HISTORY$						 #
#							 #
##########################################################

set cam_post_dir [MOM_ask_env_var UGII_CAM_POST_DIR]
set cam_debug_dir [MOM_ask_env_var UGII_CAM_DEBUG_DIR]
source ${cam_post_dir}/ugpost_base.tcl
#********Setting the debug mode ON/OFF*********
# source [MOM_ask_env_var UGII_CAM_DEBUG_DIR]mom_debug.tcl ; source [MOM_ask_env_var UGII_CAM_DEBUG_DIR]mom_review.tcl ; MOM_set_debug_mode ON 

########## SYSTEM VARIABLE DECLARATIONS ##############
set mom_sys_program_stop_code                 			0  
set mom_sys_optional_stop_code                			1  
set mom_sys_end_of_program_code               			2  
set mom_sys_spindle_direction_code(CLW)       			3  
set mom_sys_spindle_direction_code(CCLW)      			4  
set mom_sys_spindle_direction_code(OFF)       			5  
set mom_sys_coolant_code(MIST)                			8
set mom_sys_coolant_code(ON)                  			8	  
set mom_sys_coolant_code(TAP)                 			8  
set mom_sys_coolant_code(FLOOD)               			8  
set mom_sys_coolant_code(OFF)                 			9  
set mom_sys_rewind_code                       				30 
set mom_sys_leader(fourth_axis)               			A  
set mom_sys_leader(fifth_axis)                				C  
####### KINEMATIC VARIABLE DECLARATIONS ##############
set mom_kin_4th_axis_ang_offset               			0.0
set mom_kin_4th_axis_center_offset(0)         			0.0
set mom_kin_4th_axis_center_offset(1)         			0.0
set mom_kin_4th_axis_center_offset(2)         			0.0
set mom_kin_4th_axis_direction                			SIGN_DETERMINES_DIRECTION
set mom_kin_4th_axis_leader                   				A  
set mom_kin_4th_axis_max_limit                			110.0
set mom_kin_4th_axis_min_incr                 			0.001
set mom_kin_4th_axis_min_limit                			-15.0
set mom_kin_4th_axis_limit_action             			Warning
set mom_kin_4th_axis_plane                    				YZ 
set mom_kin_4th_axis_rotation                 				standard
set mom_kin_4th_axis_type                     				table
set mom_kin_4th_axis_zero                     				0.0
set mom_kin_5th_axis_ang_offset               			0.0
set mom_kin_5th_axis_center_offset(0)         			0.0
set mom_kin_5th_axis_center_offset(1)         			0.0 
set mom_kin_5th_axis_center_offset(2)         			0.0 
set mom_kin_5th_axis_direction                			SIGN_DETERMINES_DIRECTION
set mom_kin_5th_axis_leader                   				C 
set mom_kin_5th_axis_max_limit                			0.0
set mom_kin_5th_axis_min_incr                 			0.001
set mom_kin_5th_axis_min_limit                			-360.0
set mom_kin_5th_axis_limit_action             			Warning
set mom_kin_5th_axis_plane                    				XY 
set mom_kin_5th_axis_rotation                 				standard
set mom_kin_5th_axis_type                     				table
set mom_kin_5th_axis_zero                     				0.0
set mom_kin_arc_output_mode                   			FULL_CIRCLE
set mom_kin_arc_valid_planes                  				XYZ
set mom_kin_clamp_time                        				2.0
set mom_kin_flush_time                        				2.0
set mom_kin_linearization_flag                				T
set mom_kin_linearization_tol                 				0.02
set mom_kin_machine_resolution                			0.001
set mom_kin_machine_type                   				 5_axis_dual_table
set mom_kin_max_arc_radius                    			99999.999
set mom_kin_min_arc_radius                    				0.001
set mom_kin_output_unit                       				MM 
set mom_kin_post_data_unit                    				MM 
set mom_kin_rapid_feed_rate                   				10000.0
set mom_kin_tool_change_time                  			12.0
set mom_kin_x_axis_limit                      				800.0
set mom_kin_y_axis_limit                      				800.0
set mom_kin_z_axis_limit                      				600.0
set mom_kin_nurbs_output_type				HEIDENHAIN_POLY
#  Listing File variables 
set mom_sys_list_output                       				OFF  
set mom_sys_header_output                     			OFF  
set mom_sys_list_file_rows                    				40   
set mom_sys_list_file_columns                 				30   
set mom_sys_warning_output                    			OFF  
set mom_sys_group_output                      				OFF  
set mom_sys_list_file_suffix                  				lpt  
set mom_list_file_suffix              				lpt  
set mom_sys_output_file_suffix                				h  
set mom_output_file_suffix                				h
set mom_spindle_speed					1000.0
# Global variables for reposition table if rotary axis limits
set real_pos_rotary_axis(3)					0.0
set real_prev_pos_rotary_axis(3)				0.0
##KINEMATIC VARIABLE DECLARATIONS FOR RESET REAL AXIS AND REPOSITION
set number_rotate_table					0
set part_rotate_table						1
set real_pos_4_axis 					0.0
set real_prev_pos_4_axis					0.0
set real_pos_5_axis 					0.0
set real_prev_pos_5_axis					0.0
set header_check_status					0
set tolerance_linear_4_axis 					5.0
set tolerance_linear_5_axis 					5.0
# ORIGIN set tolerance_linear_4_axis 				5.0
# ORIGIN set tolerance_linear_5_axis 				5.0
set  mom_reposition_distance					230.0
set  mom_reengage_distance					5.0
set  mom_reengage_feedrate					100.0
set retract_feed_distance					5.0
set retract_rapid_z_clearence 					230.0
set mom_smooth_path					"OFF"
set mom_tolerance_on_off					"OFF"
#set mom_prev_alt_pos(0)					0.0

#=============================================================
proc MOM_smooth_tool_path { } {
#=============================================================	
	global mom_smooth_path
}
#=============================================================
proc MOM_tolerance_cycle { } {
#=============================================================	
	global mom_tolerance_on_off
	global mom_operation_type
	global mom_inside_outside_tolerances
	global tolerances
	global temp
	
	MOM_force once Tol
       
  	if {$mom_operation_type == "Variable-axis Surface Contouring"  	|| 
		$mom_operation_type == "Cavity Milling"  		|| 
		$mom_operation_type == "Fixed-axis Surface Contouring"  	|| 
		$mom_operation_type == "Sequential Mill Main Operation"  	|| 
		$mom_operation_type == "Zig-Zag Surface" } {
  		set temp [expr $mom_inside_outside_tolerances(0) + $mom_inside_outside_tolerances(1)]
  		set tolerances [expr $temp/2]
  		if {$mom_tolerance_on_off == "ON"} {
  			MOM_do_template tolerances_1
  			MOM_do_template tolerances_2
  		}
  	}

}

#=============================================================
proc MOM_start_of_program { } {
#=============================================================
  	global mom_logname mom_date is_from
  	global mom_coolant_status mom_cutcom_status
  	global mom_clamp_status mom_cycle_status
  	global mom_spindle_status mom_cutcom_plane
  	global mom_cutcom_adjust_register mom_tool_adjust_register
  	global mom_tool_length_adjust_register mom_length_comp_register
  	global mom_flush_register mom_wire_cutcom_adjust_register
  
  	set mom_coolant_status UNDEFINED
	set mom_cutcom_status  UNDEFINED
  	set mom_clamp_status   UNDEFINED
  	set mom_cycle_status   UNDEFINED
  	set mom_spindle_status UNDEFINED
  	set mom_cutcom_plane   UNDEFINED
  
  	catch {unset mom_cutcom_adjust_register}
  	catch {unset mom_tool_adjust_register}
  	catch {unset mom_tool_length_adjust_register}
  	catch {unset mom_length_comp_register}
  	catch {unset mom_flush_register}
  	catch {unset mom_wire_cutcom_adjust_register}
  
  	set is_from ""
  	OPEN_files ; #open warning and listing files
  	LIST_FILE_HEADER ; #list header in commentary listing
	MOM_start_of_group 
}
#=============================================================
proc  DELAY_TIME_SET { } {
#=============================================================
  	global mom_sys_delay_param mom_delay_value
  	global mom_delay_revs mom_delay_mode delay_time

  	if {[info exists mom_sys_delay_param(${mom_delay_mode},FORMAT)] != 0} {
    		MOM_set_address_format dwell $mom_sys_delay_param(${mom_delay_mode},FORMAT)
  	}
  	switch $mom_delay_mode {
    		SECONDS {set delay_time $mom_delay_value}
    			default {set delay_time $mom_delay_revs}
  	}
}
#=============================================================
proc  MOM_before_motion { } {
#=============================================================
  	global mom_motion_event 
  	global mom_motion_type
  	global mom_pos
  	global mom_nxt_tool_axis
  	
  	FEEDRATE_SET
  	switch $mom_motion_type {
    		ENGAGE {PB_engage_move}
    		APPROACH {PB_approach_move}
    		FIRSTCUT {PB_first_cut}
  	}
  	if {[llength [info commands PB_CMD_before_motion]]} {PB_CMD_before_motion}
}
#=============================================================
proc MOM_start_of_group {} {
#=============================================================
	global mom_output_file_basename 
	global mom_path_name 
	global header_check_status
	global mom_point1_pos 
	global mom_point2_pos
	
	set mom_point1_pos(0) -100.0
	set mom_point1_pos(1) -100.0
	set mom_point1_pos(2) -50.0
	set mom_point2_pos(0) 100.0
	set mom_point2_pos(1) 100.0
	set mom_point2_pos(2) 0.0
	 
	set mom_output_file_basename [string toupper $mom_output_file_basename ]
	if { $header_check_status == 0} { 
		MOM_output_literal "BEGIN PGM $mom_output_file_basename MM"
		set header_check_status 1
		MOM_block_create
	}       
}
#=============================================================
proc MOM_machine_mode {} {
#=============================================================
}
#=============================================================
proc PB_start_of_program { } {
#=============================================================
}
#=============================================================
proc MOM_block_create { } {
#=============================================================	
	global mom_point1_pos
	global mom_point2_pos
	MOM_force once X Y Z
	MOM_do_template start_block
	MOM_do_template end_block
}
#=============================================================
proc MOM_spindle_orient { } {
#=============================================================	
	global mom_angle_orient
	MOM_force once Angle
	MOM_do_template spindle_orient_1
	MOM_do_template spindle_orient_2
}	
#=============================================================
proc MOM_start_of_path { } {
#=============================================================
  	PB_CMD_Start_of_Operation_force_addresses
}
#=============================================================
proc MOM_nurbs_move { } {
#=============================================================
	global mom_nurbs_point_count
	global mom_nurbs_points
	global mom_nurbs_coefficients
	global xe ye ze
	global ii
	global x0 x1 x2
	global y0 y1 y2
	global z0 z1 z2
	
	for {set ii 1} {$ii < [expr $mom_nurbs_point_count-1]} {incr ii} {
		set xe $mom_nurbs_points($ii,0) 
		set ye $mom_nurbs_points($ii,1)
		set ze $mom_nurbs_points($ii,2)
		set x0 $mom_nurbs_coefficients($ii,0)
		set x1 $mom_nurbs_coefficients($ii,1)
		set x2 $mom_nurbs_coefficients($ii,2)
		set y0 $mom_nurbs_coefficients($ii,3)
		set y1 $mom_nurbs_coefficients($ii,4)
		set y2 $mom_nurbs_coefficients($ii,5)
		set z0 $mom_nurbs_coefficients($ii,6)
		set z1 $mom_nurbs_coefficients($ii,7)
		set z2 $mom_nurbs_coefficients($ii,8)
		MOM_do_template spline_end_point
		MOM_suppress always N
		MOM_do_template spline_coefficients_x
		MOM_do_template spline_coefficients_y
		MOM_do_template spline_coefficients_z
		MOM_suppress off    N	
	}
}
#=============================================================
proc MOM_from_move { } {
#=============================================================
  	global mom_feed_rate mom_feed_rate_per_rev  mom_motion_type mom_kin_max_fpm mom_pos mom_prev_pos

 	COOLANT_SET ; CUTCOM_SET ; SPINDLE_SET ; RAPID_SET ;  MODES_SET
}
#=============================================================
proc MOM_initial_move { } {
#=============================================================
  	global mom_motion_type
  	global mom_pos mom_prev_pos
  	  	
  	if {$mom_motion_type == "RAPID" } {
		if {$mom_pos(2) < $mom_prev_pos(2) } {
   			MOM_do_template rapid_cycle_xy
   			MOM_do_template rapid_cycle_z
   		} else {
   			MOM_do_template rapid_cycle_z
   			MOM_do_template rapid_cycle_xy
   		}	
  	} elseif { $mom_motion_type == "CYCLE" } {
  		MOM_rapid_cycle
  	} else {
  		MOM_linear_move
  	}
}
#=============================================================
proc MOM_first_move { } {
#=============================================================
  	global mom_feed_rate mom_feed_rate_per_rev mom_motion_type  mom_kin_max_fpm mom_pos mom_prev_pos 
  	global is_from
  	COOLANT_SET ; CUTCOM_SET ; SPINDLE_SET ; RAPID_SET ;  MODES_SET

	if {[info exists mom_kin_max_fpm] != 0} {
	if {$mom_feed_rate >= $mom_kin_max_fpm}  {MOM_rapid_move ; return}}
	if {$mom_motion_type == "RAPID"} {MOM_rapid_move} else {MOM_linear_move}
	
	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
	}
}
#=============================================================
proc MOM_end_of_path { } {
#=============================================================
}
#=============================================================
proc MOM_end_of_program { } {
#=============================================================
   	global mom_output_file_basename 
    	MOM_do_template end_of_program
	MOM_output_literal "END PGM $mom_output_file_basename MM"	

  	LIST_FILE_TRAILER
  	
  	CLOSE_files
}
#=============================================================
proc MOM_set_modes { } {
#=============================================================
  	MODES_SET
}
#=============================================================
proc MOM_first_tool { } {
#=============================================================
}
#=============================================================
proc MOM_load_tool { } {
#=============================================================
}
#=============================================================
proc MOM_msys { } {
#=============================================================
	global mom_spindle_speed
	set mom_spindle_speed 9999.0
	MOM_spindle_rpm
}

#=============================================================
proc MOM_spindle_rpm { } {
#=============================================================
	global mom_tool_number
	global mom_spindle_speed
	global line
	global mom_tool_name

   	set line [format "TOOL CALL %d Z S%.0f ; %s" $mom_tool_number $mom_spindle_speed $mom_tool_name]
   	MOM_output_literal "$line"	
   	MOM_do_template spindle_rpm 	
}

#=============================================================
proc MOM_spindle_off { } {
#=============================================================
    	MOM_do_template spindle_off
}
#=============================================================
proc MOM_coolant_on { } {
#=============================================================
  	COOLANT_SET
    	MOM_do_template coolant_on
}
#=============================================================
proc MOM_coolant_off { } {
#=============================================================
  	COOLANT_SET
    	MOM_do_template coolant_off
}
#=============================================================
proc MOM_cutcom_on { } {
#=============================================================
	global mom_cutcom_mode
	global cutcom_mode 
	global mom_cutcom_status
	set cutcom_mode "R"
   	if {$mom_cutcom_mode == "OFF"} {
      		set cutcom_mode "0"
   	} elseif {$mom_cutcom_mode == "RIGHT"} {
      		set cutcom_mode "R"
   	} elseif {$mom_cutcom_mode == "LEFT"} {
      		set cutcom_mode "L"
   	} elseif {$mom_cutcom_mode == "ON"} {
      		set cutcom_mode "R"
   	}
   	if {$mom_cutcom_status == "OFF"} {
   		set 	cutcom_mode "0"
   	}	
}
#=============================================================
proc MOM_cutcom_off { } {
#=============================================================
	global cutcom_mode
	set cutcom_mode "0"
	MOM_force once R
}
#=============================================================
proc MOM_delay { } {
#=============================================================
  	DELAY_TIME_SET
    	MOM_do_template delay_1
    	MOM_do_template delay_2
}
#=============================================================
proc MOM_opstop { } {
#=============================================================
	MOM_do_template opstop
}
#=============================================================
proc MOM_opskip { } {
#=============================================================
	OPSKIP_SET
}
#=============================================================
proc MOM_auxfun { } {
#=============================================================
	MOM_do_template auxfun
}
#=============================================================
proc MOM_prefun { } {
#=============================================================
	MOM_do_template prefun
}
#=============================================================
proc MOM_stop { } {
#=============================================================
	MOM_do_template stop
}
#=============================================================
proc MOM_linear_move { } {
#=============================================================
	global cutcom_mode
	global mom_pos
	global mom_smooth_path
	
	if {$mom_smooth_path == "OFF"} {
		MOM_do_template linear_move
	} else {
		MOM_do_template linear_move_m90
	}
}
#=============================================================
proc MOM_rotate { } {
#=============================================================
	global cutcom_mode
	global mom_pos
	global mom_alt_pos
	global mom_rotate_axis_type
	global mom_rotation_mode
	global mom_rotation_angle
	global mom_rotation_direction
	global real_prev_pos_5_axis

	if {$mom_rotation_mode == "ABSOLUTE" } {
		if {$mom_rotate_axis_type == "CAXIS" } {set mom_pos(4) $mom_rotation_angle }
		if {$mom_rotate_axis_type == "AAXIS" } {set mom_pos(3) $mom_rotation_angle }
	}

	MOM_do_template linear_move
}

#=============================================================
proc MOM_circular_move { } {
#=============================================================
	global mom_arc_direction
	global mom_arc_axis
	
	if {$mom_arc_axis(2) == "1" || $mom_arc_axis(2) == "-1"} {
		MOM_force once XC YC
		MOM_suppress once ZC
	} elseif {$mom_arc_axis(1) == "1" || $mom_arc_axis(1) == "-1"} {
		 MOM_force once XC ZC
		 MOM_suppress once YC
	} elseif {$mom_arc_axis(0) == "1" || $mom_arc_axis(0) == "-1"} {
		 MOM_force once YC ZC
		 MOM_suppress once XC
	}	 
   	MOM_do_template circle_center
   	if {$mom_arc_axis(2) == "1" || $mom_arc_axis(2) == "-1"} {
		 MOM_force once X Y
		MOM_suppress once Z
	} elseif {$mom_arc_axis(1) == "1" || $mom_arc_axis(1) == "-1"} {
		 MOM_force once X Z		 
		 MOM_suppress once Y
	} elseif {$mom_arc_axis(0) == "1" || $mom_arc_axis(0) == "-1"} {
		 MOM_force once Y Z
		 MOM_suppress once X
	}
   	if { $mom_arc_direction == "CLW"} {
      		MOM_do_template circle_end_cw
   	} elseif { $mom_arc_direction == "CCLW" } {
     		MOM_do_template circle_end_ccw
   	}
}
#=============================================================
proc MOM_rapid_cycle { } {
#=============================================================
	global mom_pos
   	global mom_prev_pos

   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
}	

#=============================================================
proc MOM_rapid_move { } {
#=============================================================
	global mom_feed_rate
	MOM_do_template rapid_move
}
#=============================================================
proc MOM_drill { } {
#=============================================================
  	global dwell_at_top
  	global surface_coordinate
  	global mom_cycle_delay_mode
  	global mom_cycle_feed_to
       
 	MOM_force once Q200 Q201 Q206 Q202 Q210 Q203 Q204 Q211
  	
  	set surface_coordinate "0.0"
  	set dwell_at_top "0.0"
  	if {$mom_cycle_delay_mode == "OFF"} {
  		set dwell_at_top 0.0
  	} else {
  		set 	dwell_at_top 0.1
  	}
  	MOM_do_template cycle_200
  	MOM_suppress always N
  	MOM_do_template tnc_q200
  	MOM_do_template tnc_q201
  	MOM_do_template tnc_q206
  	set mom_cycle_feed_to [expr abs($mom_cycle_feed_to)]  	
  	MOM_do_template tnc_q202
  	MOM_do_template tnc_q210
  	MOM_do_template tnc_q203
 	MOM_do_template tnc_q204
  	MOM_do_template tnc_q211
  	MOM_suppress off    N	
}

#=============================================================
proc  MOM_drill_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}

#=============================================================
proc MOM_drill_dwell { } {
#=============================================================
  	global dwell_at_top
  	global surface_coordinate
  	global mom_cycle_delay_mode
  	global mom_cycle_delay
  	global mom_cycle_delay_revs
  	global mom_cycle_feed_to
  	
   	MOM_force once Q200 Q201 Q206 Q202 Q210 Q203 Q204 Q211
  	
  	set surface_coordinate "0.0"
  	set dwell_at_top "0.0"
  	if {$mom_cycle_delay_mode == "OFF"} {
  		set dwell_at_top 0.0
  	} else {
		set 	dwell_at_top $mom_cycle_delay
    	}
  	MOM_do_template cycle_200
  	MOM_suppress always N
  	MOM_do_template tnc_q200
  	MOM_do_template tnc_q201
  	MOM_do_template tnc_q206
  	set mom_cycle_feed_to [expr abs($mom_cycle_feed_to)]  	
  	MOM_do_template tnc_q202
  	MOM_do_template tnc_q210
  	MOM_do_template tnc_q203
 	MOM_do_template tnc_q204
  	MOM_do_template tnc_q211
  	MOM_suppress off    N	
}

#=============================================================
proc  MOM_drill_dwell_move { } {
#=============================================================
	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}

#=============================================================
proc MOM_drill_deep { } {
#=============================================================
  	global dwell_at_top
  	global surface_coordinate
  	global mom_cycle_delay_mode
  	global mom_cycle_delay
  	global mom_cycle_cam
  	global mom_cycle_feed_to
  	
  	set mom_cycle_cam "0"
   	
   	MOM_force once Q200 Q201 Q206 Q202 Q210 Q203 Q204 Q211 Q212 Q213 Q205 Q208 Q256
  	
  	set surface_coordinate "0.0"
  	set dwell_at_top "0.0"
  	if {$mom_cycle_delay_mode == "OFF"} {
  		set dwell_at_top 0.0
  	} else {
		set  dwell_at_top $mom_cycle_delay
    	}
  	MOM_do_template cycle_203
  	MOM_suppress always N
  	MOM_do_template tnc_q200
  	MOM_do_template tnc_q201
  	MOM_do_template tnc_q206
  	MOM_do_template tnc_q202_1
  	MOM_do_template tnc_q210
  	MOM_do_template tnc_q203
 	MOM_do_template tnc_q204
 	MOM_do_template tnc_q212
	set mom_cycle_cam $mom_cycle_cam
  	MOM_do_template tnc_q213
  	MOM_do_template tnc_q205
  	MOM_do_template tnc_q211
  	MOM_do_template tnc_q208
	MOM_force once Q256
  	MOM_do_template tnc_q256
  	MOM_suppress off    N	
}
#=============================================================
proc  MOM_drill_deep_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_drill_break_chip { } {
#=============================================================
}
#=============================================================
proc  MOM_drill_break_chip_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_tap { } {
#=============================================================
}
#=============================================================
proc  MOM_tap_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore_drag { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_drag_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore_no_drag { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_no_drag_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore_manual { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_manual_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore_dwell { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_dwell_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore_back { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_back_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_bore_manual_dwell { } {
#=============================================================
}
#=============================================================
proc  MOM_bore_manual_dwell_move { } {
#=============================================================
   	global mom_pos
   	global mom_prev_pos
   	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}
  	MOM_do_template cycle_call
}
#=============================================================
proc MOM_sequence_number { } {
#=============================================================
}
#=============================================================
proc PB_CMD_before_motion { } {
#=============================================================
}
#=============================================================
proc PB_CMD_Start_of_Operation_force_addresses { } {
#=============================================================
	MOM_force once M_spindle S X Y Z R F
}

#=============================================================
proc PB_engage_move { } {
#=============================================================
}
#=============================================================
proc PB_first_cut { } {
#=============================================================
}
#=============================================================
proc PB_return_move { } {
#=============================================================
}
#=============================================================
proc MOM_gohome_move { } {
#=============================================================
	global mom_pos
	global mom_prev_pos 
	global mom_mcs_goto
	global number_rotate_table 
	global part_rotate_table 
	set mom_pos(0)	$mom_mcs_goto(0)
	set mom_pos(1)	$mom_mcs_goto(1)
	set mom_pos(2)	$mom_mcs_goto(2)

	if {$mom_pos(2) < $mom_prev_pos(2) } {
   		MOM_do_template rapid_cycle_xy
   		MOM_do_template rapid_cycle_z
   	} else {
   		MOM_do_template rapid_cycle_z
   		MOM_do_template rapid_cycle_xy
   	}	
}
